This function is used as a routine by adaptive_analysis_norm_global and sample_size_norm_global.
work_test_norm_global(
overall_sig_level = 0.025,
work_beta = 0.05,
cond_alpha = overall_sig_level,
cost_type_1_err = 0,
cost_type_2_err = 0,
prev_cost = 0,
min_effect_size = 1,
effect_size = 0,
basic_schedule_num = 50,
basic_schedule_power = 2,
basic_schedule = 0,
prior_dist = 0,
prev_time = 0,
time = 0,
next_time = 0,
stat = 0,
input_check = TRUE,
out_process = FALSE,
simpson_div = 6,
tol_boundary = 1e-08,
tol_cost = 1e-08
)List of values of the parameters specified, information of the working test, and the conditional probability of rejecting the null hypothesis.
Overall significance level in (0, 1). Default is 0.025.
Type II error probability of the working test. Default is 0.05.
Conditional Type I error probability in (0, 1). Default is 0.025.
The loss caused by erroneously rejecting the null hypothesis. If 0 is specified, the loss leading to the working test with its Type I error probability being significance_level will be calculated. Default is 0.
The loss caused by erroneously accepting the null hypothesis. If 0 is specified, the loss will be set to the value of the maximum of the basic analysis schedule. Default is 0.
The value of cost_type_1_err of the working test in the analysis just before the current analysis.
The minimum effect size. It should be positive. The working test will be constructed to have the power of 1 - work_beta for this effect size. Default is 1.
The effect size for which the probability of rejecting the null hypothesis will be calculated. If cost_type_1_err = 0, effect_size will be forced to be the null value, 0. Default is 0.
The number of analysis of the working test. Default is 50.
Determine the intervals between analyses. Default is 2.
The basic analysis schedule arbitrarily specified by user.
Prior distribution for effect sizes of min_effect_size * 0:10 / 2.
The time of the analysis just before the current analysis. Either prev_time or next_time should be 0. See the example below.
The time of the current analysis.
The time of the next analysis. Either prev_time or next_time should be 0. See the example below.
The value of the current test statistic. The value of stat should be 0 at time = 0.
Indicate whether or not the arguments input by user contain invalid values.
The values used in calculation will be output in addition to the main output. Default is FALSE.
The precision determining the precision of numerical integration. The default value is 6.
The precision in calculation of the stopping boundary of the working test.
The precision in calculation of the loss, cost_type_1_error.
adaptive_analysis_norm_global for example of this function.